   :caption: Contents:

   readme
   installation
   usage
   snntorch
   snntorch.backprop
   snntorch.spikegen
   snntorch.spikeplot
   snntorch.surrogate
   snntorch.utils
   examples
   tutorials
   contributing
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
